@@ -1,5 +1,5 @@
 from exectools.handler import ExecImport, ExecExport
-from exectools.tools_basic import Tools, TimeSection
+from exectools.tools_basic import Tools, TimePeriod
 from exectools.tools_excel import ExecExcel
 from exectools.tools_decorator import Retry, RunTime
 from exectools.tools_coroutine import Coroutine
@@ -10,7 +10,7 @@ __all__ = [
     'ExecExport',
     'ExecExcel',
     'Tools',
-    'TimeSection',
+    'TimePeriod',
     'Retry',
     'RunTime',
     'Coroutine',
